### MODULES ###
from part import *
from material import *
from section import *
from assembly import *
from step import *
from interaction import *
from load import *
from mesh import *
from job import *
from sketch import *
from visualization import *
from connectorBehavior import *

### INPUT PARAMETERS ###
emodulus=210000000000.0
poisson=0.3
dens=65340.0
stiff=3702.0
increment=0.01
maxinc=500
tottime=5.0
dampa=0.3778
dampb=0.0053
pressure=10609000.0

### IMPORT PATRAN FILE ###
mdb.ModelFromInputFile(inputFileName='W:\Master\Shell\Svalbard.inp', name='Svalbard')
del mdb.models['Model-1']
del mdb.models['Svalbard'].steps['Step-1']

### DEFINE MATERIAL PROPERTIES ###
mdb.models['Svalbard'].materials['STEEL'].damping.setValues(alpha=dampa, beta=dampb, composite=0.0)
mdb.models['Svalbard'].materials['STEEL'].elastic.setValues(table=((emodulus, poisson), ))
mdb.models['Svalbard'].materials['STEEL'].density.setValues(table=((dens, ), ))

### DEFINE SUBMERGED NODES ###
mdb.models['Svalbard'].rootAssembly.Set(name='SUBMERGED', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[394:395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[482:483]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[504:506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[508:509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[516:517]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[518:521]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[549:553]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[592:594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[604:605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[607:614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[620:621]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[623:624]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[628:629]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[709:712]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[714:716]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[727:729]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[739:740]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[770:777]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[787:788]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[793:796]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[816:817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[825:826]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[995:996]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[999:1000]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1005:1006]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1007:1010]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1011:1012]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1014:1015]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1016:1017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1019:1020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1023:1024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1096:1097]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1098:1100]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1106:1107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1110:1111]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1119:1121]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1147:1151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1155:1157]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1161:1162]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1166:1167]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1174:1175]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1180:1181]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1187:1188]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1195:1196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7944:7950]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8009:8010]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8019:8021]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8026:8027]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8039:8040]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8052:8056]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8069:8072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8116:8117]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8131:8133]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8134:8135]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8137:8138]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8141:8142]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8145:8146]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8150:8151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8156:8157]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8162:8164]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8188:8190]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8204:8205]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8213:8215]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8231:8232]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8241:8242]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8251:8252]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8261:8262]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8271:8272]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8282:8283]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8293:8294]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8304:8305]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8315:8316]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8326:8327]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8337:8338]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8348:8349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8360:8361]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8372:8373]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8384:8385]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8396:8397]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8408:8409]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8420:8421]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8432:8433]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8444:8445]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8456:8457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8468:8469]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8480:8481]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8492:8493]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8504:8505]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8516:8517]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8528:8529]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8540:8541]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8552:8553]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8564:8565]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8577:8579]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8642:8643]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8668:8669]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8681:8682]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8694:8695]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8707:8708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8720:8721]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8733:8734]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8746:8748]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8772:8773]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8785:8786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8798:8799]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8811:8812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8824:8825]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8837:8838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8850:8851]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8863:8864]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8876:8877]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8889:8890]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8902:8903]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8915:8916]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8928:8929]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8941:8942]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8954:8955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8967:8968]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8980:8981]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8993:8994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9006:9007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9019:9020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9032:9033]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9045:9046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9058:9059]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9071:9072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9084:9085]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9096:9098]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9120:9121]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9132:9133]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9144:9145]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9156:9157]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9168:9170]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9192:9193]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9204:9205]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9216:9217]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9228:9229]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9240:9242]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9264:9265]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9276:9277]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9288:9289]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9300:9301]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9312:9314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9336:9340]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9384:9385]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9395:9396]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9406:9407]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9419:9420]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9433:9435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9443:9444]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9452:9453]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9455:9456]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9457:9459]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9460:9461]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9468:9469]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9472:9474]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9475:9476]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9477:9478]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9518:9519]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9532:9534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9535:9536]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9538:9539]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9541:9542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9545:9546]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9550:9551]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9555:9556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9560:9561]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9566:9567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9572:9573]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9579:9580]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9586:9587]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9593:9594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9601:9602]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9609:9610]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9617:9618]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9626:9627]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9635:9636]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9644:9645]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9653:9654]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9663:9664]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9673:9674]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9683:9684]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9693:9694]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9703:9704]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9713:9714]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9723:9724]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9734:9735]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9745:9746]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9756:9757]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9767:9768]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9778:9779]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9789:9790]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9800:9801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9811:9812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9822:9823]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9833:9834]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9844:9845]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9855:9856]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9866:9867]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9877:9878]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9888:9889]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9899:9900]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9910:9911]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9921:9922]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9933:9934]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9945:9946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9993:9994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10017:10018]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10029:10030]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10041:10042]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10053:10054]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10065:10066]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10077:10078]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10089:10090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10101:10102]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10113:10114]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10125:10126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10137:10138]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10149:10150]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10161:10162]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10173:10174]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10185:10186]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10197:10198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10209:10210]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10221:10222]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10233:10234]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10245:10246]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10257:10258]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10269:10270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10281:10282]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10293:10294]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10305:10306]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10317:10318]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10329:10330]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10341:10342]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10353:10354]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10365:10366]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10377:10378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10389:10390]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10401:10402]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10412:10413]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10423:10424]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10434:10435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10445:10446]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10456:10457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10467:10468]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10478:10479]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10489:10490]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10500:10501]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10511:10512]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10522:10523]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10533:10534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10544:10545]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10555:10556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10566:10567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10577:10578]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10588:10589]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10599:10600]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10610:10611]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10621:10622]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10632:10633]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10644:10645]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10654:10655]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10665:10666]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10676:10677]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10683:10684]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10686:10688]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10690:10693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10703:10705]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10707:10709]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10712:10713]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10719:10722]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10725:10726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10727:10728]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10730:10733]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10736:10737]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10738:10739]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10745:10746]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10755:10759]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10764:10765]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10769:10770]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10772:10776]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10780:10781]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10782:10783]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10791:10792]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10796:10797]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10798:10802]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10809:10810]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10814:10815]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10816:10819]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10825:10826]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10830:10831]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10832:10835]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10842:10843]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10846:10847]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10848:10851]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10862:10864]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10866:10868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10875:10876]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10878:10880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10882:10884]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10891:10892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10894:10896]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10898:10900]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10907:10908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10910:10912]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10914:10916]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10923:10924]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10926:10928]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10930:10931]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10933:10934]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10938:10941]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10944:10945]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10948:10949]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10954:10957]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10960:10961]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10964:10965]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10970:10973]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10976:10977]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10980:10981]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10986:10989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10992:10993]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10996:10997]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11002:11006]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11010:11011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11014:11015]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11020:11024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11030:11031]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11036:11040]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11046:11047]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11052:11056]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11062:11063]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11068:11072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11078:11079]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11084:11088]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11094:11095]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11100:11104]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11110:11111]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11116:11120]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11126:11127]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11132:11135]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11139:11141]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11146:11149]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11153:11155]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11160:11163]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11168:11169]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11174:11177]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11180:11181]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11182:11184]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11186:11188]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11191:11192]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11199:11201]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11206:11209]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11213:11215]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11220:11223]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11229:11230]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11232:11235]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11238:11239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11242:11243]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11247:11248]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11250:11253]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11256:11258]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11260:11263]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11267:11268]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11271:11273]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11275:11277]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11280:11281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11284:11286]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11289:11291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11294:11295]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11298:11301]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11304:11306]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11309:11310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11313:11315]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11318:11320]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11322:11323]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11329:11331]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11334:11335]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11341:11343]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11345:11347]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11352:11353]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11357:11359]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11361:11363]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11368:11369]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11373:11375]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11377:11379]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11384:11385]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11389:11391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11393:11395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11400:11401]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11405:11407]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11409:11411]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11416:11417]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11421:11423]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11427:11428]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11433:11435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11437:11439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11441:11442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11449:11451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11453:11455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11457:11458]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11465:11467]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11469:11471]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11473:11474]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11481:11482]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11483:11485]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11489:11490]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11495:11496]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11497:11499]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11501:11502]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11509:11510]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11511:11513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11515:11516]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11523:11524]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11525:11528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11533:11534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11539:11540]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11541:11544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11547:11548]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11555:11556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11557:11560]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11564:11566]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11571:11575]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11581:11582]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11587:11591]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11597:11598]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11603:11607]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11611:11613]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11618:11621]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11626:11627]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11632:11635]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11640:11641]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11646:11649]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11655:11656]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11660:11663]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11669:11670]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11674:11677]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11682:11683]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11687:11689]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11692:11693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11696:11698]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11701:11703]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11705:11707]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11710:11711]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11717:11718]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11722:11723]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11733:11734]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11738:11740]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11760:11761]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11768:11769]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11771:11772]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11776:11777]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11787:11791]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11796:11799]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11802:11805]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11808:11812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11817:11820]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11823:11824]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11828:11829]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11833:11836]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11839:11840]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11842:11843]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11849:11850]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11857:11859]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11861:11863]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11865:11868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11872:11873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11879:11882]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11886:11887]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11893:11896]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11900:11901]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11907:11908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11915:11916]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11917:11920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11923:11927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11932:11933]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11939:11943]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11948:11949]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11955:11959]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11966:11967]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11971:11975]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11980:11981]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11987:11991]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11996:11997]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12005:12006]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12010:12011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12013:12017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12021:12024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12028:12029]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12040:12041]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12043:12046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12049:12052]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12056:12057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12065:12066]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12069:12072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12075:12078]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12082:12083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12090:12091]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12095:12097]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12099:12101]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12104:12105]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12109:12110]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12117:12118]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12119:12120]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12121:12122]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12123:12124]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12125:12126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12128:12129]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12134:12135]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12137:12138]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12139:12140]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12141:12142]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12143:12144]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12150:12151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12152:12153]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12155:12156]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12157:12158]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12159:12160]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12161:12162]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12163:12164]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12166:12167]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12168:12169]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12170:12171]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12172:12173]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12174:12175]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12181:12182]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12183:12184]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12193:12194]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12195:12196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12197:12198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12199:12200]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12201:12202]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12206:12207]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12209:12210]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12211:12212]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12213:12214]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12215:12216]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12217:12218]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12219:12220]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12229:12230]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12233:12234]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12235:12236]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12237:12238]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12239:12240]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12241:12242]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12247:12248]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12251:12252]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12253:12254]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12255:12256]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12257:12258]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12263:12264]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12267:12268]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12269:12270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12271:12272]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12273:12274]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12280:12281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12283:12284]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12285:12286]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12287:12288]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12289:12290]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12297:12298]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12299:12300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12301:12302]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12303:12304]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12305:12306]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12313:12314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12315:12316]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12317:12318]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12319:12320]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12321:12322]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12329:12330]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12331:12332]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12333:12334]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12335:12336]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12337:12338]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12345:12346]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12347:12348]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12349:12350]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12351:12352]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12353:12354]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12360:12361]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12363:12364]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12365:12366]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12367:12368]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12372:12373]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12375:12376]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12377:12378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12379:12380]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12381:12382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12388:12389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12391:12392]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12393:12394]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12395:12396]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12397:12398]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12404:12405]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12407:12408]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12409:12410]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12411:12412]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12413:12414]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12420:12421]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12423:12424]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12425:12426]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12427:12428]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12429:12430]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12436:12437]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12439:12440]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12441:12442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12444:12446]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12447:12448]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12454:12455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12457:12458]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12459:12460]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12461:12462]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12463:12464]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12470:12471]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12473:12474]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12475:12476]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12477:12478]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12479:12480]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12486:12487]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12489:12490]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12491:12492]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12493:12494]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12495:12496]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12502:12503]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12505:12506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12507:12508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12509:12510]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12511:12512]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12518:12519]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12521:12522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12523:12524]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12525:12526]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12527:12528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12534:12535]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12537:12538]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12539:12540]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12541:12542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12543:12544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12550:12551]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12553:12554]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12555:12556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12557:12558]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12559:12560]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12566:12567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12569:12570]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12571:12572]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12573:12574]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12578:12579]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12580:12581]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12583:12584]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12585:12586]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12587:12588]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12592:12593]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12594:12595]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12597:12598]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12599:12600]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12601:12602]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12608:12609]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12611:12612]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12613:12614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12615:12616]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12617:12618]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12619:12620]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12621:12622]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12624:12625]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12626:12627]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12628:12629]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12638:12639]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12640:12641]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12643:12644]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12645:12646]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12647:12648]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12652:12653]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12654:12655]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12657:12658]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12659:12660]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12661:12662]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12666:12667]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12669:12670]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12671:12672]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12673:12674]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12675:12676]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12682:12683]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12684:12685]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12687:12688]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12689:12690]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12691:12692]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12693:12694]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12695:12696]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12697:12698]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12699:12700]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12701:12702]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12706:12707]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12708:12709]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12710:12711]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12712:12713]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12714:12715]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12719:12720]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12721:12722]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12723:12724]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12725:12726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12727:12728]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12729:12730]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12734:12735]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12736:12737]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12738:12739]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12740:12741]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12742:12743]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12744:12745]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12749:12750]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12751:12752]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12753:12754]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12756:12757]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12758:12759]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12760:12761]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12767:12768]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12769:12770]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12772:12773]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12779:12780]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12781:12782]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12783:12784]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12785:12786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12793:12794]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12795:12796]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12797:12798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12799:12800]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12801:12802]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12809:12810]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12811:12812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12813:12814]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12815:12816]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12817:12818]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12825:12826]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12827:12828]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12829:12830]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12832:12833]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12834:12835]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12841:12842]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12843:12844]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12845:12846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12848:12849]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12850:12851]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12857:12858]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12859:12860]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12861:12862]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12868:12869]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12871:12872]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12873:12874]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12875:12876]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12877:12878]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12880:12881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12887:12888]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12889:12890]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12891:12892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12893:12894]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12896:12897]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12903:12904]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12905:12906]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12907:12908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12909:12910]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12912:12913]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12919:12920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12921:12922]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12923:12924]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12930:12931]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12933:12934]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12935:12936]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12937:12938]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12940:12941]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12947:12948]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12949:12950]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12951:12952]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12954:12955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12961:12962]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12963:12964]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12965:12966]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12967:12968]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12974:12975]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12977:12978]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12979:12980]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12981:12982]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12983:12984]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12986:12987]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12993:12994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12995:12996]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12997:12998]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12999:13000]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13004:13005]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13006:13007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13009:13010]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13011:13012]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13013:13014]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13015:13016]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13022:13023]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13025:13026]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13027:13028]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13029:13030]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13031:13032]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13038:13039]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13041:13042]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13043:13044]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13045:13046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13047:13048]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13049:13050]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13051:13052]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13057:13058]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13059:13060]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13061:13062]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13065:13066]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13071:13072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13073:13074]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13075:13076]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13079:13080]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13085:13086]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13087:13088]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13089:13090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13095:13096]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13099:13100]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13101:13102]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13103:13104]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13109:13110]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13113:13114]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13115:13116]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13117:13118]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13122:13123]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13125:13126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13127:13128]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13132:13133]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13135:13136]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13137:13138]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13139:13140]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13141:13142]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13143:13144]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13145:13146]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13148:13149]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13155:13156]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13160:13161]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13171:13172]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13176:13177]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13179:13180]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13200:13201]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13206:13207]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13211:13212]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13214:13215]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13225:13226]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13227:13228]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13230:13231]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13232:13233]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13234:13235]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13236:13237]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13238:13239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13240:13241]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13243:13244]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13245:13246]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13247:13248]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13249:13250]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13251:13252]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13253:13254]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13261:13262]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13263:13264]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13265:13266]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13267:13268]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13270:13271]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13272:13273]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13280:13281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13287:13288]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13289:13290]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13291:13292]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13293:13294]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13295:13296]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13297:13298]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13299:13300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13302:13303]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13309:13310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13311:13312]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13313:13314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13316:13317]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13323:13324]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13325:13326]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13327:13328]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13330:13331]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13338:13339]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13345:13346]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13347:13348]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13349:13350]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13351:13352]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13353:13354]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13355:13356]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13357:13358]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13359:13360]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13362:13363]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13370:13371]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13372:13373]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13374:13375]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13376:13377]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13378:13379]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13385:13386]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13387:13388]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13389:13390]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13391:13392]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13399:13400]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13402:13403]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13404:13405]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13406:13407]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13408:13409]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13410:13411]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13418:13419]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13420:13421]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13422:13423]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13424:13425]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13426:13427]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13438:13439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13440:13441]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13443:13444]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13445:13446]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13447:13448]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13449:13450]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13452:13453]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13454:13455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13456:13457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13458:13459]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13470:13471]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13473:13474]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13475:13476]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13477:13478]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13480:13481]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13482:13483]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13484:13485]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13486:13487]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13496:13497]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13499:13500]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13501:13502]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13503:13504]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13506:13507]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13508:13509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13510:13511]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13512:13513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13522:13523]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13525:13526]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13527:13528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13530:13531]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13532:13533]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13534:13535]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13539:13540]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13542:13543]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13559:13560]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13568:13569]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13590:13591]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13630:13631]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13679:13680]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13725:13726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13736:13737]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13904:13905]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13938:13939]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14049:14050]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14138:14139]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14205:14206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14272:14273]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14333:14334]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14344:14346]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14366:14367]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14377:14378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14388:14389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14399:14400]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14409:14411]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14429:14430]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14439:14440]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14449:14450]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14458:14459]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14467:14469]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14483:14484]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14491:14492]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14498:14499]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14505:14506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14511:14512]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14516:14518]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14524:14525]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14527:14528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14529:14531]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14532:14533]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14544:14545]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14551:14552]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14569:14570]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14603:14604]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14646:14647]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14671:14672]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14688:14689]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14849:14850]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14880:14881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14981:14982]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15062:15063]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15123:15124]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15184:15185]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15239:15240]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15249:15250]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15259:15260]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15269:15270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15279:15280]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15289:15290]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15299:15300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15308:15309]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15317:15318]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15326:15327]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15335:15336]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15344:15345]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15352:15353]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15360:15361]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15370:15371]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15374:15375]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15381:15382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15387:15388]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15393:15394]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15398:15399]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15405:15407]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15409:15410]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15411:15413]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15421:15422]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15424:15425]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15426:15427]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15428:15429]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15443:15462]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15463:15465]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15471:15507]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15513:15514]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15529:15532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15533:15536]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15538:15542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15544:15546]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15821:15856]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15857:15859]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15861:15867]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15870:15874]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15875:15876]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15877:15880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15882:15886]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15888:15892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15894:15899]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15902:15909]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15910:15912]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15914:15918]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15920:15923]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15925:15930]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15932:15937]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15938:15939]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15940:15943]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15945:15953]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15954:15955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15959:15961]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15962:15966]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15967:15969]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15972:15973]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15977:15978]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15979:15983]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15987:15990]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15992:16026]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16042:16043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16151:16153]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16163:16166]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16175:16179]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16185:16189]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16202:16212]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16227:16232]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16240:16245]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16248:16249]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16254:16260]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16268:16282]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16303:16310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16318:16325]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16327:16328]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16333:16340]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16342:16343]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16348:16355]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16357:16358]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16368:16382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16386:16389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16395:16402]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16404:16406]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16412:16419]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16421:16423]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16429:16436]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16438:16440]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16446:16453]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16455:16457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16469:16483]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16487:16493]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16499:16506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16508:16511]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16517:16524]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16526:16529]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16535:16549]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16551:16562]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16570:16584]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16600:16613]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16619:16625]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16627:16633]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16639:16645]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16647:16653]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16659:16665]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16667:16673]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16679:16685]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16687:16693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16699:16705]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16707:16719]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16726:16732]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16745:16751]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16760:16766]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16770:16776]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16789:16801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16804:16817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16819:16831]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16838:16850]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16861:16873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16883:16895]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16901:16903]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16905:16913]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16919:16920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16922:16935]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16941:16942]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16944:16955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16965:16989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17001:17006]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17008:17028]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17040:17049]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17056:17068]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17075:17087]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17094:17106]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17113:17125]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17139:17163]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17170:17181]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17188:17199]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17206:17218]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17225:17242]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17249:17255]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17262:17287]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17294:17314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17321:17351]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17365:17382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17389:17400]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17407:17418]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17425:17436]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17443:17465]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17479:17490]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17497:17508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17515:17526]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17533:17544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17551:17573]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17587:17594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17601:17612]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17619:17630]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17637:17648]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17655:17672]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17686:17699]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17706:17716]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17723:17733]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17740:17750]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17757:17774]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17788:17799]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17806:17815]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17822:17831]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17838:17846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17853:17868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17889:17896]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17903:17910]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17932:17941]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17955:17986]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18017:18018]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18022:18034]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18042:18045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18062:18065]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18067:18071]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18072:18076]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18077:18087]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18090:18120]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18141:18142]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18147:18149]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18152:18162]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18414:18448]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18449:18450]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18452:18458]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18461:18465]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18466:18467]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18468:18471]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18473:18477]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18479:18483]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18485:18489]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18492:18499]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18500:18502]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18504:18508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18510:18513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18515:18520]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18522:18527]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18528:18529]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18530:18533]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18535:18543]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18544:18545]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18549:18550]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18551:18554]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18555:18556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18559:18560]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18565:18567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18571:18574]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18576:18610]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18730:18731]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18741:18743]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18752:18755]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18761:18764]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18777:18785]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18800:18804]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18812:18816]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18819:18820]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18825:18830]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18838:18850]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18871:18877]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18885:18891]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18893:18894]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18899:18905]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18907:18908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18913:18919]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18921:18922]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18932:18944]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18948:18951]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18957:18963]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18965:18967]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18973:18979]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18981:18983]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18989:18995]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18997:18999]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19005:19011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19013:19015]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19027:19039]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19043:19049]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19055:19061]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19063:19066]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19072:19078]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19080:19083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19089:19101]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19103:19113]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19121:19133]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19149:19162]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19168:19173]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19175:19181]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19187:19192]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19194:19200]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19206:19211]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19213:19219]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19225:19230]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19232:19238]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19244:19249]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19251:19262]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19269:19275]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19288:19293]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19302:19308]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19312:19317]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19330:19342]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19345:19356]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19358:19369]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19376:19387]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19398:19409]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19419:19430]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19436:19438]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19440:19447]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19453:19454]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19456:19468]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19474:19475]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19477:19487]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19497:19519]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19531:19536]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19538:19556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19568:19576]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19583:19594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19601:19612]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19619:19630]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19637:19648]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19662:19684]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19691:19701]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19708:19718]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19725:19736]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19743:19759]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19766:19772]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19779:19802]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19809:19828]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19835:19863]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19877:19892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19899:19909]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19916:19926]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19933:19943]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19950:19970]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19984:19994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20001:20011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20018:20028]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20035:20045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20052:20072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20086:20092]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20099:20109]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20116:20126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20133:20143]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20150:20165]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20179:20191]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20198:20207]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20214:20223]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20230:20239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20246:20261]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20275:20285]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20292:20300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20307:20315]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20322:20329]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20336:20349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20370:20376]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20383:20389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20411:20418]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20432:20461]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20492:20493]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20497:20508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20524:20583]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20584:20600]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20602:20605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20616:20623]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20627:20654]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20667:20719]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20721:20727]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20728:20735]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20736:20740]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20742:20745]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20756:20796])

### DEFINE LOAD PATCH ###
mdb.models['Svalbard'].rootAssembly.Set(elements=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[14624:14627]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[18076:18079]
    , name='LOADPATCH')
mdb.models['Svalbard'].rootAssembly.Surface(name='Load Patch', side1Elements=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[14624:14627]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[18076:18079])

### DEFINE BOW NODE ###
mdb.models['Svalbard'].rootAssembly.Set(name='BOW', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1616:1617])

### DEFINE BUOYANCY SPRINGS ###
mdb.models['Svalbard'].rootAssembly.engineeringFeatures.SpringDashpotToGround(
    dashpotBehavior=OFF, dashpotCoefficient=0.0, dof=3, name='Stiffness-Heave', 
    orientation=None, region=
    mdb.models['Svalbard'].rootAssembly.sets['SUBMERGED'], springBehavior=ON, 
    springStiffness=stiff)

### STEP DEFINITION ###
mdb.models['Svalbard'].ImplicitDynamicsStep(description=
    'Implicit time integration', initialInc=increment, maxNumInc=maxinc, name=
    'Dynamics', noStop=OFF, nohaf=OFF, previous='Initial', 
    timeIncrementationMethod=FIXED, timePeriod=tottime)

### OUTPUT REQUEST EVERY INCREMENT ###
mdb.models['Svalbard'].fieldOutputRequests['F-Output-1'].setValues(frequency=1)

### LOAD DEFINITION ###
mdb.models['Svalbard'].TabularAmplitude(data=((0.0, 0.0), (TIME1, AMP1), (TIME2, 
    AMP2)), name='Triangle', smooth=SOLVER_DEFAULT, timeSpan=STEP)
mdb.models['Svalbard'].Pressure(amplitude='Triangle', createStepName='Dynamics'
    , distributionType=UNIFORM, field='', magnitude=pressure, name=
    'Pressure Pulse', region=
    mdb.models['Svalbard'].rootAssembly.surfaces['Load Patch'])

### ANALYSIS ###
mdb.Job(atTime=None, contactPrint=OFF, description='', echoPrint=OFF, 
    explicitPrecision=SINGLE, getMemoryFromAnalysis=True, historyPrint=OFF, 
    memory=90, memoryUnits=PERCENTAGE, model='Svalbard', modelPrint=OFF, 
    multiprocessingMode=DEFAULT, name='Analysis', nodalOutputPrecision=SINGLE, 
    numCpus=1, queue=None, scratch='', type=ANALYSIS, userSubroutine='', 
    waitHours=0, waitMinutes=0)
mdb.jobs['Analysis'].submit(consistencyChecking=OFF)
mdb.jobs['Analysis'].waitForCompletion()

########## OUTPUT ##########

### MODULES ###
from abaqus import *
from abaqusConstants import *
from caeModules import *
from driverUtils import executeOnCaeStartup

### VIEWPORT ###
session.Viewport(name='Viewport: 1', origin=(0.0, 0.0), width=166.857147216797, 
    height=150.857147216797)
session.viewports['Viewport: 1'].makeCurrent()
session.viewports['Viewport: 1'].maximize()
executeOnCaeStartup()
session.viewports['Viewport: 1'].partDisplay.geometryOptions.setValues(
    referenceRepresentation=ON)

### ODB ###
o1 = session.openOdb(name='Analysis.odb')
session.viewports['Viewport: 1'].setValues(displayedObject=o1)

### REQUEST OUTPUT ###
odb = session.odbs['Analysis.odb']
session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('U', 
    NODAL), ), nodeSets=('BOW', ))
session.xyDataObjects.changeKey(fromName='U:U3 PI: PART-1-1 N: 269261', 
    toName='Disp-Heave')
session.xyDataObjects.changeKey(fromName='U:U1 PI: PART-1-1 N: 269261', 
    toName='Disp-Surge')
session.xyDataObjects.changeKey(fromName='U:U2 PI: PART-1-1 N: 269261', 
    toName='Disp-Sway')
session.xyDataObjects.changeKey(fromName='U:Magnitude PI: PART-1-1 N: 269261', 
    toName='Disp-Total')

### REPORT ###
x0 = session.xyDataObjects['Disp-Heave']
x1 = session.xyDataObjects['Disp-Surge']
x2 = session.xyDataObjects['Disp-Sway']
x3 = session.xyDataObjects['Disp-Total']
session.xyReportOptions.setValues(numDigits=3)
session.writeXYReport(fileName='Output.rpt', xyData=(x0, x1, x2, x3))