### MODULES ###
from part import *
from material import *
from section import *
from assembly import *
from step import *
from interaction import *
from load import *
from mesh import *
from optimization import *
from job import *
from sketch import *
from visualization import *
from connectorBehavior import *

### INPUT PARAMETERS ###
emodulus=210000000000.0
poisson=0.3
dens=65340.0
stiff=3701.9
increment=0.01
maxinc=500
dampa=0.3778
dampb=0.0053
pressure=10609000.0

### IMPORT PATRAN FILE ###
mdb.ModelFromInputFile(inputFileName='C:\Temp\Svalbard.inp', name='Svalbard')
del mdb.models['Model-1']
del mdb.models['Svalbard'].steps['Step-1']

### DEFINE MATERIAL PROPERTIES ###
mdb.models['Svalbard'].materials['STEEL'].damping.setValues(alpha=dampa, beta=dampb, composite=0.0)
mdb.models['Svalbard'].materials['STEEL'].elastic.setValues(table=((emodulus, poisson), ))
mdb.models['Svalbard'].materials['STEEL'].density.setValues(table=((dens, ), ))

### DEFINE SUBMERGED NODES (3982) ###
mdb.models['Svalbard'].rootAssembly.Set(name='SUBMERGED', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[674:676]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[679:681]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[683:689]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[691:693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[761:763]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[769:783]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[784:786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[824:825]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[855:859]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[863:881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[890:893]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[928:931]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[976:981]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[983:984]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[994:997]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[999:1000]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1002:1005]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1006:1011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1014:1016]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1021:1024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1064:1068]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1113:1119]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1120:1122]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1135:1151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1191:1193]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1236:1249]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1255:1270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1310:1313]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1356:1358]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1359:1368]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1372:1387]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1424:1427]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1429:1431]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1475:1478]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1480:1509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1546:1547]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1548:1549]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1551:1553]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1602:1604]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1605:1611]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1612:1615]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1616:1632]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1673:1674]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1676:1677]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1679:1681]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1725:1726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1728:1733]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1736:1750]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1791:1795]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1796:1797]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1843:1844]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1846:1849]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1851:1855]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1858:1869]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1906:1909]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1910:1912]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1913:1914]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1962:1967]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1971:1975]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[1981:1990]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2021:2024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2026:2027]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2030:2032]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2033:2034]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2076:2079]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2080:2081]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2083:2084]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2085:2086]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2091:2095]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2103:2110]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2138:2141]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2142:2143]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2145:2146]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2148:2149]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2150:2151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2152:2153]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2190:2193]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2194:2195]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2198:2199]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2201:2203]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2204:2205]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2214:2218]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2226:2231]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2256:2260]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2263:2264]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2265:2266]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2268:2269]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2271:2273]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2274:2275]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2304:2307]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2309:2310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2315:2316]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2317:2318]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2322:2324]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2325:2326]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2338:2342]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2350:2353]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2370:2373]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2378:2379]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2384:2386]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2388:2389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2390:2391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2393:2395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2396:2397]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2424:2428]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2430:2431]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2432:2433]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2438:2439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2440:2442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2446:2447]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2462:2466]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2478:2482]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2486:2489]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2497:2498]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2501:2502]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2507:2508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2512:2514]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2516:2517]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2518:2520]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2521:2522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2549:2555]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2556:2557]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2558:2559]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2562:2564]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2567:2568]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2587:2588]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2589:2590]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2604:2605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2612:2615]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2623:2624]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2627:2628]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2633:2634]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2637:2641]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2642:2643]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2669:2676]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2677:2680]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2685:2686]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2714:2715]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2716:2721]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2736:2738]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2739:2742]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2746:2748]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2756:2757]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2760:2761]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2766:2767]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2769:2773]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2800:2807]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2808:2809]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2811:2812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2820:2821]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2827:2830]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2843:2844]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2845:2847]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2860:2863]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2869:2873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2885:2888]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2892:2894]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2902:2903]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2906:2907]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2912:2913]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2914:2916]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2918:2919]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2938:2939]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2947:2951]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2952:2954]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2958:2959]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2962:2965]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2971:2972]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2988:2989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2990:2991]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[2997:2998]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3006:3007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3010:3011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3015:3017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3020:3021]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3027:3028]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3032:3034]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3042:3043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3046:3047]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3052:3053]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3056:3057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3071:3072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3078:3083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3085:3086]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3090:3091]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3092:3093]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3099:3101]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3106:3107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3128:3130]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3135:3136]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3143:3144]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3151:3152]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3155:3157]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3163:3165]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3174:3175]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3179:3181]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3189:3190]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3193:3194]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3203:3204]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3205:3206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3227:3233]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3235:3240]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3245:3246]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3250:3256]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3266:3267]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3280:3281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3287:3288]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3290:3291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3298:3299]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3306:3307]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3310:3312]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3317:3322]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3326:3327]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3330:3334]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3337:3338]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3339:3340]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3348:3349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3354:3355]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3363:3364]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3378:3379]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3381:3383]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3384:3387]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3390:3391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3392:3393]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3394:3395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3406:3409]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3410:3411]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3419:3420]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3434:3435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3441:3442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3444:3445]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3452:3453]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3460:3461]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3464:3465]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3467:3468]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3472:3473]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3476:3477]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3480:3481]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3484:3485]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3486:3487]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3494:3495]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3499:3500]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3505:3506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3525:3530]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3534:3540]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3542:3543]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3544:3546]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3557:3560]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3561:3562]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3568:3569]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3582:3583]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3589:3590]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3592:3593]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3600:3601]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3608:3609]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3613:3614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3615:3616]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3619:3620]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3623:3628]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3631:3632]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3635:3636]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3637:3638]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3643:3644]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3648:3649]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3664:3667]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3669:3670]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3674:3675]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3679:3680]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3682:3683]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3685:3687]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3690:3692]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3705:3708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3709:3710]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3716:3717]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3730:3731]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3737:3738]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3740:3741]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3748:3749]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3756:3757]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3761:3763]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3766:3767]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3770:3771]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3774:3775]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3780:3781]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3783:3784]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3791:3792]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3815:3816]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3818:3819]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3822:3823]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3824:3825]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3827:3828]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3829:3830]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3833:3834]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3838:3841]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3844:3846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3858:3861]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3862:3863]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3869:3870]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3883:3884]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3890:3891]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3893:3894]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3901:3902]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3910:3912]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3915:3916]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3919:3920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3923:3924]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3929:3930]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3934:3935]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3936:3937]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3968:3969]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3971:3972]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3974:3976]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3978:3980]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3983:3984]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3988:3989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3990:3991]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[3994:3996]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4001:4003]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4012:4015]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4016:4017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4023:4024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4037:4038]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4044:4045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4047:4048]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4056:4057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4063:4065]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4068:4069]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4072:4073]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4078:4079]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4083:4084]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4089:4090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4121:4123]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4126:4127]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4129:4131]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4134:4136]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4141:4143]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4144:4145]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4150:4152]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4154:4156]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4165:4168]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4169:4170]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4176:4177]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4190:4191]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4197:4198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4201:4202]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4210:4212]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4217:4218]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4221:4222]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4227:4228]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4232:4233]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4238:4239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4271:4274]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4278:4280]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4283:4285]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4287:4288]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4291:4292]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4295:4296]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4301:4302]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4304:4306]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4308:4310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4319:4322]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4323:4324]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4333:4334]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4347:4348]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4355:4356]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4358:4359]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4363:4364]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4367:4368]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4373:4374]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4379:4380]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4384:4385]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4390:4391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4424:4427]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4428:4429]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4431:4434]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4435:4436]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4438:4439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4441:4442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4446:4447]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4449:4450]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4452:4454]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4456:4458]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4470:4473]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4474:4475]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4483:4484]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4497:4498]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4505:4506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4508:4509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4512:4513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4516:4517]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4522:4523]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4526:4527]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4531:4532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4561:4564]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4568:4570]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4573:4574]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4576:4578]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4581:4582]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4585:4586]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4591:4592]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4594:4595]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4597:4598]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4600:4602]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4604:4605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4608:4609]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4620:4623]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4624:4625]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4633:4634]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4647:4648]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4655:4656]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4657:4658]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4661:4662]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4667:4668]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4674:4675]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4680:4681]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4714:4717]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4721:4722]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4723:4724]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4726:4728]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4733:4736]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4739:4740]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4745:4746]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4748:4749]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4751:4752]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4754:4755]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4760:4762]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4765:4766]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4767:4768]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4779:4782]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4783:4784]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4792:4793]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4806:4808]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4814:4815]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4816:4817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4822:4823]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4827:4828]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4835:4836]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4869:4870]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4872:4873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4874:4875]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4877:4878]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4879:4881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4884:4885]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4886:4887]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4890:4891]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4894:4896]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4901:4902]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4904:4905]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4907:4908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4913:4914]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4917:4918]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4921:4923]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4926:4927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4928:4929]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4943:4946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4947:4948]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4957:4958]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4962:4963]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4971:4972]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4978:4979]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4982:4983]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4987:4988]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[4991:4992]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5026:5027]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5029:5030]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5031:5033]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5035:5036]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5037:5038]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5041:5043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5045:5046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5047:5048]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5051:5052]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5057:5059]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5061:5062]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5067:5068]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5071:5072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5075:5076]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5079:5080]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5083:5085]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5088:5089]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5090:5091]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5107:5110]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5111:5112]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5121:5122]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5125:5126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5134:5135]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5143:5144]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5146:5147]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5150:5151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5156:5157]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5183:5186]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5190:5191]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5193:5196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5197:5198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5201:5203]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5205:5206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5209:5210]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5213:5214]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5219:5220]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5225:5226]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5227:5228]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5230:5231]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5234:5235]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5238:5239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5242:5243]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5246:5247]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5253:5255]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5259:5260]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5261:5262]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5276:5279]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5280:5281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5289:5290]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5293:5294]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5304:5305]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5309:5310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5314:5315]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5316:5317]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5322:5324]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5349:5352]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5354:5355]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5356:5358]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5360:5363]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5366:5367]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5369:5370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5377:5378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5381:5382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5385:5386]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5387:5388]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5390:5391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5394:5395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5398:5399]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5405:5406]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5410:5411]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5415:5417]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5421:5422]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5423:5424]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5438:5441]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5443:5444]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5450:5451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5454:5455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5463:5464]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5467:5468]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5472:5473]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5492:5496]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5500:5501]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5502:5505]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5507:5508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5511:5513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5515:5517]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5526:5527]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5533:5534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5537:5538]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5541:5542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5545:5546]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5547:5548]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5550:5551]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5557:5558]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5562:5563]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5567:5568]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5572:5573]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5577:5579]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5583:5584]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5585:5586]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5600:5604]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5613:5614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5618:5619]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5628:5629]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5634:5635]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5657:5662]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5663:5664]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5668:5669]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5670:5671]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5674:5676]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5678:5679]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5681:5682]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5686:5687]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5696:5697]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5700:5701]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5704:5705]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5708:5709]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5715:5716]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5717:5718]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5721:5722]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5726:5727]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5731:5732]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5736:5737]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5741:5742]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5746:5747]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5751:5752]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5753:5756]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5760:5761]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5771:5776]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5777:5779]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5785:5786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5790:5791]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5797:5798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5803:5804]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5827:5831]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5834:5835]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5837:5838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5840:5841]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5843:5844]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5845:5846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5848:5849]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5853:5854]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5858:5859]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5867:5868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5874:5875]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5879:5880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5884:5885]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5889:5890]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5891:5892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5895:5896]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5900:5901]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5905:5906]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5910:5911]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5915:5916]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5920:5921]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5925:5926]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5927:5928]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5932:5933]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5944:5946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5948:5949]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5955:5956]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5960:5961]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5968:5969]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5991:5994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5997:6000]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6002:6003]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6004:6005]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6008:6009]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6011:6012]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6016:6017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6021:6022]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6028:6029]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6038:6039]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6043:6044]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6048:6049]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6053:6054]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6058:6059]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6060:6061]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6064:6065]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6069:6070]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6074:6075]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6079:6080]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6084:6085]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6089:6090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6094:6095]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6096:6097]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6101:6102]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6111:6112]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6114:6115]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6116:6117]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6123:6124]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6127:6128]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6151:6154]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6156:6158]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6160:6162]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6163:6164]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6170:6171]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6172:6173]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6175:6176]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6178:6179]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6183:6184]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6193:6194]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6198:6199]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6206:6207]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6211:6212]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6216:6217]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6221:6222]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6226:6227]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6228:6229]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6232:6233]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6237:6238]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6242:6243]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6247:6248]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6252:6253]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6257:6258]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6262:6263]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6264:6265]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6268:6269]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6279:6281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6282:6283]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6290:6291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6296:6297]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6314:6321]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6322:6323]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6324:6325]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6330:6332]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6334:6335]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6340:6341]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6348:6349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6353:6354]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6358:6359]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6366:6367]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6371:6372]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6376:6377]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6381:6382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6386:6387]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6388:6389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6392:6393]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6397:6398]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6402:6403]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6407:6408]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6412:6413]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6417:6418]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6422:6424]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6427:6428]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6435:6437]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6444:6446]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6461:6469]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6472:6473]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6475:6476]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6477:6479]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6483:6484]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6497:6498]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6505:6506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6510:6511]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6515:6516]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6520:6521]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6528:6529]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6533:6534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6538:6539]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6543:6544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6548:6549]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6550:6551]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6554:6555]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6559:6560]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6564:6565]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6569:6570]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6574:6575]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6579:6580]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6583:6584]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6586:6587]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6591:6592]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6596:6597]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6600:6601]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6606:6607]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6626:6634]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6636:6637]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6639:6640]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6642:6643]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6648:6649]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6667:6668]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6673:6674]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6678:6679]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6683:6684]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6688:6689]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6696:6697]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6701:6702]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6706:6707]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6711:6712]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6716:6717]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6718:6719]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6722:6723]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6728:6729]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6733:6734]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6738:6739]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6743:6744]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6747:6748]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6753:6754]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6758:6759]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6763:6764]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6769:6770]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6789:6798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6800:6801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6803:6804]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6806:6807]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6812:6813]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6836:6837]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6841:6842]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6846:6847]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6851:6852]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6856:6857]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6864:6865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6869:6870]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6874:6875]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6879:6880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6884:6885]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6886:6887]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6891:6892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6896:6897]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6901:6902]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6906:6907]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6910:6911]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6916:6917]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6921:6922]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6926:6927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6932:6933]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6952:6962]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6964:6965]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6967:6968]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6970:6971]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[6976:6977]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7004:7005]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7009:7010]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7014:7015]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7019:7020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7024:7025]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7032:7033]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7037:7038]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7042:7043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7047:7048]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7052:7053]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7054:7055]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7059:7060]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7064:7065]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7069:7070]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7073:7074]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7079:7080]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7084:7085]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7089:7090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7095:7096]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7115:7126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7129:7130]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7131:7132]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7134:7135]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7140:7141]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7172:7173]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7177:7178]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7182:7183]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7187:7188]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7192:7193]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7200:7201]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7205:7206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7210:7211]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7215:7216]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7220:7221]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7222:7223]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7227:7228]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7232:7233]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7236:7237]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7242:7243]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7247:7248]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7252:7253]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7258:7259]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7278:7291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7293:7295]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7299:7300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7331:7332]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7336:7337]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7341:7342]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7346:7347]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7351:7352]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7359:7360]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7364:7365]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7369:7370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7374:7375]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7379:7380]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7381:7382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7386:7387]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7390:7391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7394:7395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7398:7399]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7402:7403]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7407:7408]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7423:7437]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7440:7441]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7447:7448]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7450:7451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7490:7494]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7498:7499]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7503:7504]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7508:7509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7513:7514]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7521:7522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7526:7527]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7531:7532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7536:7537]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7541:7542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7543:7544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7547:7548]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7553:7554]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7558:7559]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7563:7564]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7569:7570]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7589:7600]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7603:7604]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7606:7607]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7609:7610]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7616:7620]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7621:7622]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7662:7664]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7668:7669]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7673:7674]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7678:7679]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7683:7684]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7691:7692]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7696:7697]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7701:7702]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7706:7707]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7711:7713]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7718:7719]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7723:7724]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7728:7729]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7734:7735]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7754:7764]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7767:7768]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7771:7772]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7778:7779]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7783:7789]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7830:7832]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7836:7837]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7841:7842]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7846:7847]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7851:7852]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7859:7860]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7864:7865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7869:7870]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7874:7875]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7878:7879]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7884:7885]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7889:7890]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7895:7896]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7915:7924]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7929:7930]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7932:7933]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7936:7937]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7948:7956]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[7996:7998]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8002:8003]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8007:8008]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8012:8013]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8017:8018]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8025:8026]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8030:8031]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8035:8036]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8039:8040]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8045:8046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8050:8051]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8056:8057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8076:8083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8087:8088]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8091:8092]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8094:8095]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8098:8099]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8104:8113]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8124:8136]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8170:8173]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8176:8180]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8184:8185]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8189:8190]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8194:8195]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8199:8200]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8207:8208]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8212:8213]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8216:8217]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8222:8223]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8227:8228]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8233:8234]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8253:8258]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8261:8262]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8265:8266]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8267:8268]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8269:8270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8272:8273]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8278:8285]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8295:8304]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8332:8338]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8343:8346]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8349:8350]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8354:8355]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8359:8360]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8364:8365]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8369:8370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8377:8378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8381:8382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8385:8386]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8389:8390]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8394:8395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8410:8414]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8420:8421]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8423:8424]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8427:8428]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8430:8431]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8434:8435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8448:8454]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8456:8457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8458:8462]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8467:8475]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8483:8486]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8502:8504]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8508:8511]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8516:8518]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8521:8522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8523:8524]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8527:8528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8532:8533]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8537:8538]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8542:8543]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8549:8550]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8555:8556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8560:8561]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8566:8567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8586:8588]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8594:8595]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8597:8598]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8599:8600]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8604:8605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8607:8608]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8611:8612]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8627:8632]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8634:8636]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8637:8638]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8643:8647]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8655:8660]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8676:8677]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8681:8682]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8687:8688]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8691:8692]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8693:8694]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8697:8698]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8702:8703]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8707:8708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8711:8712]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8720:8721]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8725:8726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8731:8732]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8757:8758]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8760:8761]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8763:8764]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8765:8766]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8769:8770]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8773:8774]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8777:8778]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8795:8802]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8804:8806]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8807:8808]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8813:8815]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8823:8830]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8846:8847]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8851:8852]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8857:8858]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8861:8862]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8863:8864]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8867:8868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8872:8873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8876:8877]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8882:8883]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8890:8891]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8896:8897]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8926:8927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8929:8930]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8931:8932]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8935:8936]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8938:8939]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8941:8942]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8945:8946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8965:8973]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8975:8977]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8978:8979]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8982:8983]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8985:8986]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8990:8991]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[8995:8999]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9015:9017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9021:9022]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9027:9028]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9031:9032]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9033:9034]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9037:9038]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9041:9042]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9047:9048]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9052:9053]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9057:9058]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9063:9064]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9096:9099]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9100:9101]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9102:9103]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9106:9107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9109:9110]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9112:9113]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9116:9117]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9138:9147]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9149:9151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9152:9153]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9156:9157]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9159:9160]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9164:9165]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9169:9171]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9183:9186]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9190:9191]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9195:9196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9201:9202]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9205:9206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9209:9210]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9215:9216]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9220:9221]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9225:9226]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9231:9232]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9263:9266]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9268:9269]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9271:9272]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9273:9274]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9277:9278]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9280:9281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9283:9284]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9287:9288]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9311:9318]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9320:9321]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9322:9323]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9326:9327]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9329:9330]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9334:9335]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9342:9344]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9352:9353]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9357:9359]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9363:9364]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9368:9369]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9373:9374]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9377:9378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9383:9384]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9388:9389]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9393:9394]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9399:9400]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9430:9433]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9435:9436]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9438:9439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9440:9441]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9444:9445]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9447:9448]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9450:9451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9457:9458]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9480:9487]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9493:9494]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9495:9496]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9499:9500]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9502:9503]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9507:9508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9513:9515]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9523:9524]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9528:9529]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9533:9534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9538:9539]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9542:9543]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9548:9549]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9553:9554]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9558:9559]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9564:9565]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9591:9594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9598:9599]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9601:9602]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9604:9605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9606:9607]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9610:9611]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9613:9614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9619:9620]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9627:9628]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9648:9655]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9663:9664]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9665:9666]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9669:9670]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9672:9673]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9677:9678]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9683:9685]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9693:9694]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9698:9699]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9703:9704]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9707:9708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9713:9714]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9718:9719]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9723:9724]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9729:9730]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9756:9759]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9761:9763]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9767:9768]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9770:9771]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9772:9773]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9774:9775]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9779:9780]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9785:9786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9790:9791]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9807:9814]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9824:9825]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9826:9827]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9830:9831]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9833:9834]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9838:9839]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9844:9846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9854:9855]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9859:9860]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9863:9864]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9867:9868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9871:9872]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9875:9876]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9880:9881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9902:9905]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9907:9908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9909:9910]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9912:9914]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9918:9919]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9920:9921]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9927:9928]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9934:9935]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9939:9940]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9945:9946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9966:9973]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9989:9990]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9991:9992]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9995:9996]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[9998:9999]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10003:10004]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10009:10011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10019:10020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10023:10024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10029:10030]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10034:10035]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10039:10040]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10045:10046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10067:10071]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10073:10074]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10076:10078]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10079:10080]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10082:10084]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10086:10087]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10091:10092]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10099:10100]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10104:10105]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10109:10110]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10115:10116]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10136:10143]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10163:10164]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10165:10166]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10169:10170]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10172:10174]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10178:10179]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10184:10186]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10190:10191]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10194:10195]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10200:10201]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10205:10206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10210:10211]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10216:10217]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10238:10244]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10246:10247]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10248:10249]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10250:10251]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10252:10253]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10258:10259]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10264:10265]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10270:10271]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10275:10276]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10280:10281]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10286:10287]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10307:10314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10338:10339]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10340:10341]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10344:10345]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10346:10347]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10348:10349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10353:10354]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10359:10360]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10363:10364]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10369:10370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10374:10375]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10379:10380]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10385:10386]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10406:10409]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10410:10415]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10417:10418]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10419:10420]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10421:10422]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10430:10431]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10434:10435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10440:10441]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10445:10446]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10450:10451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10456:10457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10481:10488]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10512:10513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10514:10515]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10521:10522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10523:10524]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10525:10526]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10530:10531]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10535:10536]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10541:10542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10546:10547]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10551:10552]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10557:10558]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10577:10581]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10582:10583]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10584:10589]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10594:10595]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10596:10597]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10598:10599]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10604:10605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10610:10611]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10615:10616]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10622:10623]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10626:10627]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10657:10664]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10665:10668]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10696:10697]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10698:10699]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10703:10704]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10705:10706]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10707:10708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10711:10712]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10718:10719]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10723:10724]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10730:10731]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10734:10735]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10754:10757]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10758:10759]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10760:10765]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10769:10770]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10771:10773]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10780:10781]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10785:10786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10792:10793]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10797:10798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10828:10831]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10834:10841]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10842:10844]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10876:10877]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10878:10879]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10883:10884]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10885:10887]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10892:10893]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10898:10899]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10905:10906]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10910:10911]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10929:10932]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10933:10934]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10935:10940]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10944:10946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10948:10949]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10955:10956]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10962:10963]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10967:10968]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[10994:10997]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11003:11004]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11006:11007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11010:11017]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11018:11020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11056:11057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11058:11059]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11063:11065]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11067:11068]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11072:11073]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11080:11081]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11085:11086]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11104:11107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11108:11109]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11110:11115]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11118:11119]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11121:11123]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11132:11133]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11137:11138]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11159:11160]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11164:11167]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11169:11170]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11172:11173]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11179:11180]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11182:11183]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11186:11193]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11194:11196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11236:11237]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11238:11239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11242:11243]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11245:11247]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11254:11255]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11256:11257]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11260:11261]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11279:11282]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11283:11284]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11285:11290]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11292:11294]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11302:11303]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11306:11307]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11324:11327]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11332:11334]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11336:11337]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11339:11340]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11346:11347]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11349:11350]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11356:11363]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11364:11366]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11407:11409]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11414:11416]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11420:11421]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11424:11425]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11436:11439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11440:11444]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11447:11451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11455:11457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11462:11463]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11467:11468]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11482:11485]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11494:11497]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11498:11499]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11501:11502]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11507:11509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11511:11512]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11514:11515]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11524:11525]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11531:11532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11536:11545]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11546:11548]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11585:11586]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11588:11589]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11591:11592]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11595:11596]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11600:11602]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11604:11605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11609:11610]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11624:11628]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11629:11631]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11639:11641]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11646:11647]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11661:11662]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11664:11665]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11666:11667]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11668:11671]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11673:11674]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11677:11678]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11679:11680]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11682:11683]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11688:11690]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11692:11693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11695:11696]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11711:11712]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11716:11717]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11721:11726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11727:11729]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11749:11750]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11766:11768]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11772:11773]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11774:11775]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11776:11777]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11782:11783]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11785:11786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11802:11806]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11810:11811]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11815:11817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11819:11820]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11835:11836]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11837:11838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11839:11840]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11841:11842]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11843:11847]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11850:11851]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11854:11855]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11856:11857]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11859:11860]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11865:11867]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11872:11873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11879:11880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11894:11895]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11899:11900]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11904:11907]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11908:11909]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11924:11927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11931:11932]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11938:11939]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11950:11951]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11954:11955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11956:11957]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11962:11963]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11978:11980]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11985:11989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[11993:11994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12005:12010]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12011:12018]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12021:12022]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12025:12026]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12027:12028]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12030:12031]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12043:12045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12049:12050]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12054:12055]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12070:12071]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12075:12076]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12080:12081]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12082:12083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12094:12097]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12101:12103]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12106:12107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12110:12113]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12122:12124]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12126:12127]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12147:12148]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12149:12153]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12154:12155]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12156:12158]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12164:12165]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12169:12170]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12179:12180]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12183:12184]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12186:12191]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12194:12195]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12198:12199]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12203:12204]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12210:12211]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12220:12222]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12226:12227]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12231:12232]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12248:12249]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12253:12254]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12258:12259]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12260:12261]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12264:12265]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12269:12270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12274:12275]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12278:12279]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12284:12285]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12289:12290]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12299:12301]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12312:12313]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12329:12332]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12333:12335]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12336:12338]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12339:12341]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12343:12344]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12348:12349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12350:12351]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12352:12353]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12362:12367]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12373:12374]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12381:12382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12385:12386]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12390:12391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12400:12402]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12406:12407]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12411:12412]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12429:12430]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12434:12435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12439:12440]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12441:12442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12445:12446]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12450:12451]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12454:12455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12460:12461]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12465:12466]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12469:12470]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12478:12479]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12489:12492]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12495:12496]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12505:12506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12507:12509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12510:12513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12515:12516]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12517:12518]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12519:12520]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12524:12525]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12542:12547]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12551:12552]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12557:12558]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12561:12562]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12566:12567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12576:12578]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12582:12583]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12587:12588]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12606:12607]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12611:12612]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12615:12616]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12617:12618]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12621:12622]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12625:12626]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12631:12632]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12636:12637]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12640:12641]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12644:12645]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12665:12668]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12669:12670]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12671:12672]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12681:12683]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12684:12687]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12689:12690]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12691:12692]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12693:12694]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12696:12697]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12717:12722]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12726:12727]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12732:12733]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12736:12737]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12741:12742]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12751:12752]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12756:12757]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12761:12762]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12780:12782]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12786:12787]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12790:12791]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12794:12795]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12800:12801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12805:12806]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12809:12810]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12813:12814]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12831:12835]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12840:12842]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12843:12844]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12845:12846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12847:12848]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12859:12862]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12864:12865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12866:12867]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12868:12869]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12871:12872]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12895:12900]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12904:12905]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12910:12911]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12914:12915]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12919:12920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12929:12931]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12935:12936]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12940:12941]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12945:12946]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12963:12964]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12967:12968]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12971:12972]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12977:12978]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12982:12983]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12986:12987]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[12990:12991]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13006:13008]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13011:13013]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13014:13015]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13017:13018]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13019:13020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13021:13022]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13023:13024]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13025:13026]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13033:13034]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13037:13038]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13040:13041]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13042:13043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13044:13045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13046:13047]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13074:13078]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13082:13083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13091:13092]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13095:13096]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13100:13101]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13106:13107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13111:13112]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13116:13117]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13121:13122]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13126:13127]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13140:13141]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13144:13145]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13150:13151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13155:13156]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13162:13163]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13166:13167]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13183:13187]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13188:13190]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13191:13192]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13193:13194]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13195:13196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13197:13198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13199:13200]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13201:13202]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13206:13207]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13212:13213]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13214:13216]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13248:13252]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13260:13261]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13267:13268]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13271:13272]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13276:13277]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13281:13282]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13286:13287]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13291:13292]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13296:13297]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13301:13302]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13309:13310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13318:13319]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13323:13324]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13329:13330]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13350:13355]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13356:13359]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13360:13361]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13362:13363]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13364:13365]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13366:13367]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13368:13370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13374:13375]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13377:13378]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13382:13384]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13422:13428]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13434:13435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13441:13443]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13446:13447]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13451:13452]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13456:13457]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13461:13462]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13466:13467]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13471:13472]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13475:13476]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13482:13483]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13488:13489]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13494:13495]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13499:13500]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13520:13525]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13526:13528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13529:13530]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13531:13532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13533:13534]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13535:13537]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13539:13540]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13543:13544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13546:13547]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13548:13549]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13567:13569]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13595:13599]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13605:13606]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13612:13614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13617:13618]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13622:13623]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13627:13628]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13632:13633]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13637:13638]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13641:13642]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13647:13648]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13655:13656]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13661:13662]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13666:13667]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13687:13693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13694:13696]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13697:13698]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13699:13700]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13701:13703]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13707:13708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13709:13710]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13712:13714]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13736:13740]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13768:13772]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13778:13780]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13786:13788]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13791:13792]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13796:13797]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13801:13802]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13806:13807]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13810:13811]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13816:13817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13821:13822]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13828:13829]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13833:13834]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13854:13860]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13861:13863]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13864:13865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13866:13868]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13872:13873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13875:13876]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13877:13878]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13879:13880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13901:13903]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13909:13910]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13911:13912]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13938:13943]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13949:13950]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13956:13958]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13961:13962]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13966:13967]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13971:13972]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13975:13976]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13981:13982]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13986:13987]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13993:13994]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[13998:13999]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14019:14026]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14027:14029]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14030:14032]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14036:14037]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14039:14040]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14042:14043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14045:14046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14072:14076]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14080:14081]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14082:14083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14109:14115]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14121:14122]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14128:14130]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14133:14134]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14138:14139]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14142:14143]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14148:14149]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14153:14154]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14160:14161]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14165:14166]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14186:14193]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14194:14196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14198:14199]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14201:14202]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14204:14205]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14207:14208]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14209:14210]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14242:14246]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14250:14251]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14252:14253]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14279:14285]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14291:14292]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14298:14300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14303:14304]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14307:14308]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14313:14314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14318:14319]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14325:14326]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14330:14331]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14351:14360]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14363:14365]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14366:14367]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14369:14370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14396:14401]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14406:14408]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14412:14413]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14414:14415]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14425:14427]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14443:14449]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14455:14456]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14458:14459]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14462:14463]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14466:14467]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14470:14471]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14474:14475]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14480:14481]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14484:14485]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14500:14509]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14511:14512]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14517:14518]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14519:14520]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14521:14522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14534:14535]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14539:14542]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14554:14556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14564:14567]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14572:14574]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14578:14579]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14580:14581]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14591:14593]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14609:14614]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14620:14622]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14625:14626]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14631:14632]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14636:14637]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14643:14644]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14648:14649]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14668:14675]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14678:14679]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14680:14681]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14687:14688]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14689:14690]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14696:14701]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14712:14713]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14715:14717]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14726:14727]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14729:14730]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14738:14739]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14744:14746]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14750:14751]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14752:14753]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14759:14760]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14764:14765]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14775:14777]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14782:14785]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14787:14788]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14791:14792]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14794:14795]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14799:14800]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14804:14805]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14811:14812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14816:14817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14836:14838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14840:14843]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14844:14846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14847:14848]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14849:14850]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14851:14852]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14864:14865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14870:14871]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14879:14880]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14882:14884]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14893:14894]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14896:14897]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14905:14906]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14911:14913]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14917:14918]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14919:14920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14926:14927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14931:14932]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14938:14939]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14943:14944]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14949:14950]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14951:14952]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14957:14958]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14962:14963]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14969:14970]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14974:14975]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14996:15002]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15006:15007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15008:15010]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15011:15013]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15030:15031]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15034:15035]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15042:15043]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15045:15047]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15056:15057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15059:15060]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15068:15069]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15074:15076]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15080:15081]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15082:15083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15089:15090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15094:15095]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15101:15102]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15106:15107]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15111:15113]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15116:15117]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15121:15122]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15128:15129]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15133:15134]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15155:15158]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15163:15164]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15168:15172]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15175:15176]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15177:15179]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15194:15195]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15197:15198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15205:15206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15208:15210]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15219:15220]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15222:15223]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15231:15232]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15237:15239]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15243:15244]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15245:15246]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15252:15253]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15257:15258]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15264:15265]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15268:15269]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15275:15276]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15278:15279]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15285:15286]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15290:15291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15313:15324]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15326:15328]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15330:15331]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15333:15334]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15338:15340]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15354:15355]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15357:15358]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15365:15366]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15368:15370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15378:15379]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15381:15382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15390:15391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15396:15398]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15402:15403]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15404:15405]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15411:15412]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15416:15417]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15422:15423]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15426:15427]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15432:15433]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15434:15435]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15438:15439]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15454:15455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15468:15470]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15472:15475]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15477:15479]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15480:15481]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15482:15483]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15484:15485]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15489:15490]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15494:15496]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15507:15508]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15510:15511]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15518:15519]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15521:15523]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15531:15532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15534:15535]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15543:15544]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15549:15551]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15555:15556]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15557:15558]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15563:15564]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15567:15568]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15575:15576]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15582:15583]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15588:15589]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15590:15591]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15610:15611]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15616:15617]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15629:15634]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15638:15640]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15642:15644]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15646:15647]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15651:15652]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15655:15657]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15667:15668]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15670:15671]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15678:15679]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15681:15683]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15691:15692]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15694:15695]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15702:15703]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15708:15709]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15713:15714]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15715:15716]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15720:15721]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15726:15727]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15735:15736]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15741:15742]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15746:15747]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15763:15764]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15765:15766]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15783:15786]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15789:15793]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15796:15798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15800:15801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15803:15804]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15807:15808]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15811:15813]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15823:15824]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15826:15827]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15834:15835]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15837:15839]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15847:15848]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15850:15851]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15858:15859]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15864:15865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15869:15871]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15877:15878]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15882:15883]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15892:15893]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15897:15898]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15913:15914]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15932:15933]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15935:15937]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15938:15941]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15944:15945]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15946:15947]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15948:15949]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15952:15954]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15956:15957]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15963:15964]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15967:15969]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15979:15980]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15986:15987]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15994:15995]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[15997:15999]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16007:16008]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16010:16011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16018:16019]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16024:16025]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16028:16029]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16031:16032]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16037:16038]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16044:16045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16049:16050]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16081:16085]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16090:16092]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16093:16097]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16100:16101]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16103:16105]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16107:16108]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16114:16115]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16118:16120]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16134:16135]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16139:16140]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16147:16148]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16150:16152]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16160:16161]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16163:16164]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16171:16172]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16176:16177]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16182:16183]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16188:16189]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16195:16196]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16225:16228]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16231:16232]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16235:16236]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16237:16238]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16240:16241]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16248:16251]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16254:16255]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16257:16259]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16261:16262]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16271:16272]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16275:16277]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16290:16291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16295:16296]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16303:16304]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16305:16307]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16315:16316]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16318:16319]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16325:16326]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16330:16332]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16335:16336]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16341:16342]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16367:16370]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16373:16374]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16376:16377]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16382:16383]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16386:16388]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16394:16397]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16400:16401]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16403:16405]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16407:16408]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16417:16418]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16421:16423]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16436:16437]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16441:16442]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16449:16450]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16451:16452]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16459:16460]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16462:16463]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16471:16472]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16476:16477]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16479:16480]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16483:16484]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16518:16520]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16522:16523]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16524:16525]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16526:16527]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16530:16531]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16538:16541]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16547:16550]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16554:16555]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16557:16559]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16561:16562]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16570:16571]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16574:16576]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16589:16590]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16594:16595]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16602:16603]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16604:16605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16610:16611]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16615:16616]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16623:16624]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16628:16629]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16630:16631]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16664:16665]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16666:16668]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16670:16671]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16672:16673]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16677:16678]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16686:16687]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16690:16693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16698:16701]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16705:16706]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16708:16710]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16712:16713]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16720:16721]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16724:16726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16739:16740]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16744:16745]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16752:16754]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16761:16762]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16765:16766]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16773:16774]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16779:16780]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16809:16811]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16812:16813]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16816:16817]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16821:16822]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16826:16827]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16828:16829]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16839:16842]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16847:16850]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16853:16854]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16856:16858]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16860:16861]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16868:16869]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16871:16873]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16886:16887]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16891:16892]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16898:16899]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16901:16902]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16907:16908]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16911:16912]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16919:16920]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16948:16951]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16956:16957]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16958:16959]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16962:16963]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16965:16966]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16970:16971]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16974:16977]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16982:16985]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16988:16989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16991:16993]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[16995:16996]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17003:17004]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17006:17007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17019:17020]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17024:17025]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17030:17031]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17035:17036]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17041:17042]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17044:17045]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17080:17083]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17088:17090]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17105:17106]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17108:17109]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17118:17119]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17122:17123]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17139:17142]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17153:17154]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17165:17167]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17177:17178]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17180:17182]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17184:17185]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17204:17205]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17207:17208]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17224:17225]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17229:17230]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17233:17234]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17237:17238]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17241:17242]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17291:17295]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17296:17297]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17298:17300]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17310:17311]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17313:17314]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17316:17317]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17320:17323]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17342:17343]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17344:17346]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17355:17356]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17359:17361]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17367:17368]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17390:17391]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17392:17393]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17421:17422]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17435:17436]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17444:17445]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17454:17455]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17503:17506]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17520:17522]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17524:17525]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17527:17528]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17530:17532]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17540:17541]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17544:17545]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17552:17553]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17556:17557]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17558:17559]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17569:17570]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17571:17573]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17581:17582]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17583:17586]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17593:17594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17595:17596]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17606:17607]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17611:17612]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17614:17615]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17637:17641]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17654:17657]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17659:17660]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17661:17662]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17663:17664]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17666:17667]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17671:17673]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17679:17680]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17690:17691]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17692:17693]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17694:17695]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17707:17708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17709:17711]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17718:17720]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17722:17723]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17730:17731]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17733:17734]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17744:17745]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17749:17750]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17776:17780]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17795:17796]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17797:17798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17801:17802]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17803:17804]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17805:17806]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17807:17808]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17809:17810]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17813:17815]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17832:17833]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17834:17835]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17836:17837]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17847:17848]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17850:17851]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17852:17854]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17862:17865]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17871:17872]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17873:17874]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17877:17878]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17880:17881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17890:17891]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17923:17927]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17928:17930]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17939:17941]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17946:17947]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17948:17950]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17953:17955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17964:17965]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17966:17967]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17968:17969]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17981:17982]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17985:17988]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[17994:17995]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18000:18001]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18002:18003]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18006:18007]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18008:18009]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18049:18052]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18055:18057]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18059:18060]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18062:18065]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18071:18072]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18076:18078]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18079:18080]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18084:18086]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18088:18089]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18090:18091]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18098:18100]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18111:18112]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18113:18114]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18115:18116]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18125:18126]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18128:18129]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18131:18132]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18139:18140]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18144:18145]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18147:18148]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18181:18184]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18186:18187]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18193:18195]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18197:18198]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18205:18206]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18210:18211]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18212:18213]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18214:18215]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18217:18218]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18226:18227]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18239:18240]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18241:18243]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18253:18256]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18259:18260]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18266:18270]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18273:18275]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18277:18278]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18318:18323]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18328:18329]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18332:18333]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18335:18336]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18340:18341]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18345:18346]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18348:18349]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18350:18351]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18352:18353]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18360:18361]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18368:18369]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18377:18379]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18381:18382]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18391:18392]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18395:18396]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18402:18403]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18404:18406]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18466:18471]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18475:18476]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18486:18487]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18499:18500]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18506:18507]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18510:18511]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18525:18526]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18530:18531]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18542:18543]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18563:18564]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18570:18571]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18615:18616]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18618:18619]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18632:18634]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18675:18677]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18680:18681]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18686:18688]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18690:18691]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18695:18696]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18698:18700]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18707:18708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18713:18714]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18716:18717]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18724:18726]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18744:18745]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18751:18752]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18798:18801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18802:18803]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18806:18808]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18811:18813]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18814:18815]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18817:18818]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18820:18821]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18828:18829]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18836:18838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18840:18841]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18844:18846]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18940:18943]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18946:18947]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18948:18951]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18954:18955]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18957:18958]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18965:18966]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18970:18972]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18977:18978]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18980:18981]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18984:18985]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[18988:18989]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19010:19011]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19012:19013]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19026:19027]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19035:19036]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19045:19046]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19050:19051]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19118:19121]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19124:19130]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19131:19132]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19140:19143]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19150:19151]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19155:19156]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19176:19177]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19182:19183]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19187:19188]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19257:19261]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19269:19271]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19276:19277]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19280:19285]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19290:19291]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19309:19310]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19314:19315]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19319:19320]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19378:19383]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19389:19392]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19393:19395]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19400:19401]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19407:19410]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19431:19432]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19434:19437]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19439:19440]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19496:19501]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19503:19505]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19506:19507]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19512:19513]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19516:19518]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19524:19526]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19577:19578]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19579:19584]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19591:19594]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19602:19603]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19604:19605]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19611:19613]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19678:19680]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19681:19684]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19693:19695]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19697:19698]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19701:19702]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19707:19708]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19710:19711]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19793:19794]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19796:19798]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19799:19801]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19803:19805]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19806:19807]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19810:19812]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19874:19876]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19877:19879]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19880:19881]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[19957:19962]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20039:20042]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20118:20119]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20133:20134])

### DEFINE LOAD PATCH ###
mdb.models['Svalbard'].rootAssembly.Set(elements=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20770:20771]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20826:20827]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20836:20838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20897:20898]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20899:20900]
    , name='LOADPATCH')
mdb.models['Svalbard'].rootAssembly.Surface(name='Load Patch', side1Elements=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20770:20771]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20826:20827]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20836:20838]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20897:20898]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].elements[20899:20900])

### DEFINE BOW NODE ###
mdb.models['Svalbard'].rootAssembly.Set(name='BOW', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20268:20269])

### DEFINE BC NODES AND CONSTRAINTS ###
mdb.models['Svalbard'].rootAssembly.Set(name='SURGENODE', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[112:113])
mdb.models['Svalbard'].rootAssembly.Set(name='SWAYYAWNODES', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[5550:5551]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[14738:14739])
mdb.models['Svalbard'].rootAssembly.Set(name='ROLLNODES', nodes=
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[306:307]+\
    mdb.models['Svalbard'].rootAssembly.instances['PART-1-1'].nodes[20273:20274])
mdb.models['Svalbard'].DisplacementBC(amplitude=UNSET, createStepName='Initial'
    , distributionType=UNIFORM, fieldName='', localCsys=None, name='BC-Surge', 
    region=mdb.models['Svalbard'].rootAssembly.sets['SURGENODE'], u1=SET, u2=
    UNSET, u3=UNSET, ur1=UNSET, ur2=UNSET, ur3=UNSET)
mdb.models['Svalbard'].DisplacementBC(amplitude=UNSET, createStepName='Initial'
    , distributionType=UNIFORM, fieldName='', localCsys=None, name='BC_SwayYaw'
    , region=mdb.models['Svalbard'].rootAssembly.sets['SWAYYAWNODES'], u1=UNSET
    , u2=SET, u3=UNSET, ur1=UNSET, ur2=UNSET, ur3=UNSET)
mdb.models['Svalbard'].DisplacementBC(amplitude=UNSET, createStepName='Initial'
    , distributionType=UNIFORM, fieldName='', localCsys=None, name='BC-Roll', 
    region=mdb.models['Svalbard'].rootAssembly.sets['ROLLNODES'], u1=UNSET, u2=
    UNSET, u3=UNSET, ur1=SET, ur2=UNSET, ur3=UNSET)

### DEFINE BUOYANCY SPRINGS ###
mdb.models['Svalbard'].rootAssembly.engineeringFeatures.SpringDashpotToGround(
    dashpotBehavior=OFF, dashpotCoefficient=0.0, dof=3, name='Stiffness-Heave', 
    orientation=None, region=
    mdb.models['Svalbard'].rootAssembly.sets['SUBMERGED'], springBehavior=ON, 
    springStiffness=stiff)

### STEP DEFINITION ###
mdb.models['Svalbard'].StaticStep(initialInc=increment, maxNumInc=maxinc, name=
    'Quasistatic-Ramp-On', noStop=OFF, previous='Initial', 
    timeIncrementationMethod=FIXED, timePeriod=0.125)
mdb.models['Svalbard'].StaticStep(initialInc=increment, maxNumInc=maxinc, name=
    'Quasistatic-Ramp-Off', noStop=OFF, previous='Quasistatic-Ramp-On', 
    timeIncrementationMethod=FIXED, timePeriod=0.125)

### LOAD DEFINITION ###
mdb.models['Svalbard'].Pressure(amplitude=UNSET, createStepName=
    'Quasistatic-Ramp-On', distributionType=UNIFORM, field='', magnitude=
    4*pressure, name='Pressure Pulse', region=
    mdb.models['Svalbard'].rootAssembly.surfaces['Load Patch'])
mdb.models['Svalbard'].loads['Pressure Pulse'].deactivate('Quasistatic-Ramp-Off')

### ANALYSIS ###
mdb.Job(atTime=None, contactPrint=OFF, description='', echoPrint=OFF, 
    explicitPrecision=SINGLE, getMemoryFromAnalysis=True, historyPrint=OFF, 
    memory=90, memoryUnits=PERCENTAGE, model='Svalbard', modelPrint=OFF, 
    multiprocessingMode=DEFAULT, name='Analysis', nodalOutputPrecision=SINGLE, 
    numCpus=1, queue=None, scratch='', type=ANALYSIS, userSubroutine='', 
    waitHours=0, waitMinutes=0)
mdb.jobs['Analysis'].submit(consistencyChecking=OFF)
mdb.jobs['Analysis'].waitForCompletion()

########## OUTPUT ##########

### MODULES ###
from abaqus import *
from abaqusConstants import *
from caeModules import *
from driverUtils import executeOnCaeStartup

### VIEWPORT ###
session.Viewport(name='Viewport: 1', origin=(0.0, 0.0), width=166.857147216797, 
    height=150.857147216797)
session.viewports['Viewport: 1'].makeCurrent()
session.viewports['Viewport: 1'].maximize()
executeOnCaeStartup()
session.viewports['Viewport: 1'].partDisplay.geometryOptions.setValues(
    referenceRepresentation=ON)

### ODB ###
o1 = session.openOdb(name='Analysis.odb')
session.viewports['Viewport: 1'].setValues(displayedObject=o1)

### REQUEST OUTPUT ###
odb = session.odbs['Analysis.odb']
session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('U', 
    NODAL), ), nodeSets=('BOW', ))
session.xyDataObjects.changeKey(fromName='U:U3 PI: PART-1-1 N: 20269', 
    toName='Disp-Heave')
session.xyDataObjects.changeKey(fromName='U:U1 PI: PART-1-1 N: 20269', 
    toName='Disp-Surge')
session.xyDataObjects.changeKey(fromName='U:U2 PI: PART-1-1 N: 20269', 
    toName='Disp-Sway')
session.xyDataObjects.changeKey(fromName='U:Magnitude PI: PART-1-1 N: 20269', 
    toName='Disp-Total')

### REPORT ###
x0 = session.xyDataObjects['Disp-Heave']
x1 = session.xyDataObjects['Disp-Surge']
x2 = session.xyDataObjects['Disp-Sway']
x3 = session.xyDataObjects['Disp-Total']
session.xyReportOptions.setValues(numDigits=3)
session.writeXYReport(fileName='Output.rpt', xyData=(x0, x1, x2, x3))